#[non_exhaustive]pub struct UnstableInvitePermissionConfigEventContent {
pub block_all: bool,
}Expand description
The content of an org.matrix.msc4380.invite_permission_config account data, the
unstable version of InvitePermissionConfigEventContent.
Controls whether invites to this account are permitted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.block_all: boolWhen set to true, indicates that the user does not wish to receive any room invites, and they should be blocked.
Implementations